# TAPREF -- Set up local aperture reference file for one TRES spectrum
# By Doug Mink, SAO Telescope Data Center
# June 6, 2008

procedure tapref (image)

file	image=""	{prompt="Image for which to find aperture reference"}

file	aproot="flat"	{prompt="Root filename for aperature reference spectrum"}
int	fiber=1		{prompt="Fiber 1 2 or 3"}
file	apdir="tresdata$"	{prompt="Directory for reference spectra"}
file	imref=""	{prompt="Aperture reference file (returned)"}
string	apsize="s"	{prompt="Fiber size s(mall) m(edium) l(arge)"}
string	binning=""	{prompt="Binned by two if =b"}
bool	verbose=yes	{prompt="Log progress (y or n)"}
bool	debug=yes	{prompt="Print debugging information (y or n)"}

begin
	bool vb, db
	string apr, apstring
	file apref, adir, appath, apnew, impath, imin
	string args

	if (imin != "") {
	    tfib1 (imin, specdir="")
	    fiber = tfib1.fiber
	    if (fiber == "12")
		fiber = "1"
	    apsize = tfib1.apsize
	    binning = tfib1.binning
	    }
	adir = apdir
	fixdir (adir)
	adir = fixdir.newdir
	if (adir == "") {
	    adir = "tresdata$"
	    }
	apr = aproot
	if (apr == "") {
	    apr = "flat"
	    }
	vb = verbose
	db = debug

	if (!access ("database/"))
	    mkdir ("database")

# Get file names for fiber reference image and aperture file
	apstring = apr // apsize // binning // fiber

# Link fiber reference image file to local directory
	imref = apstring // ".fits"
	impath = adir // imref
	if (!access (imref)) {
	    if (!access (impath)) {
		imref = ""
		print ("TAPREF: ", impath, " does not exist")
		return
		}
	    else if (db)
		print ("TAPREF: Copying ",impath, " to ",imref)
	    args = osfn (impath) // " " // imref
	    lns (args)
	    }
	else if (db)
	    print ("TAPREF: ",imref," already exists")

# Copy fiber reference aperture file to local database/
	apref = "ap" // apstring
	appath = adir // "database/" // apref
	apnew = "database/" // apref
	if (!access (apnew)) {
	    if (!access (appath)) {
		imref = ""
		print ("TAPREF: ", appath, " does not exist")
		return
		}
	    else if (db)
		print ("TAPREF: ",appath," => ", apnew)
	    args = osfn (appath) // " " // apnew
	    lns (args)
	    }
	else if (db)
	    print ("TAPREF: ",apnew," already exists")

	if (vb)
	    print (impath)

	return
end

# Oct  3 2007	New task
# Oct 10 2007	CL scripts cannot return parameters; make filenames internal

# Jan 10 2008	Change tresfib to trsfib
# Jun  6 2008	Call TRSFIB1 instead of TRSFIB
# Jan 28 2008	Rewrite to do only one fiber
# Jan 30 2008	Change parameters to allow for image argument
