# File tres/Scripts/trsavg.cl
# July 31, 2008
# By Doug Mink, SAO Telescope Data Center

# TRSAVG - Use mscred.combine to make an average of a list of images

procedure trsavg (images)

string	images=""	{prompt="Images to combine"}
int	sumseq=201	{prompt="Sequence number to use for output file"}
string	outroot=""	{prompt="Root of output file name"}
file	outfile=""	{prompt="Output file name (returned)"}
bool	deltemp=yes	{prompt="Delete intermediate image files (y or n)"}
bool	verbose=yes	{prompt="Print process progress (y or n)"}

begin

file	templist, imout, imin1
string	tchar, imagelist, history, dstring, oroot, fn1, fn2
file	listfile, imfile
bool	dellist, vb, done
int	nfiles
real	mjdsum, mjdavg, exptot

	vb = verbose
	dellist = deltemp
	imagelist = images
	exptot = 0.0
	fn1 = "0"
	oroot = outroot
	sumseq = trssum.sumseq

# Load needed packages if necessary
	if (!defpac ("mscred"))
	    mscred

#  Make temporary list of input files
	templist = mktemp ("tempcombine") // ".list"
	files (imagelist, >templist)

# Count files and initialize output root name
	nfiles = 0
	done = yes
	list = templist
	mjdsum = 0.0
	while (fscan (list,imin1) != EOF) {
	    nfiles = nfiles + 1
	    if (nfiles == 1) {
		smatch (imin1, ".fits")
		if (oroot == "") {
		    if (smatch.found) {
			oroot = substr (imin1, 6, smatch.start-1)
			}
		    else {
			oroot = substr (imin1, 6, 100)
			}
		    fn1 = substr (imin1,1,4)
		    }
		}
	    imgetp.value = 0.0
	    imgetp (imin1, "EXPTIME")
	    exptot = exptot + real (imgetp.value)
	    imgetp.value = 0.0
	    imgetp (imin1, "MJD")
	    mjdsum = mjdsum + real (imgetp.value)
	    fn2 = substr (imin1,1,4)
	    }
	if (nfiles == 0) {
	    print ("TRSAVG: No files to process")
	    return
	    }
	else if (nfiles == 1) {
	    print ("TRSAVG: Only one file, returning it as an average")
	    }
	else if (vb) {
	    print ("TRSAVG is adding ",nfiles," files from ", imagelist)
	    }
	mjdavg = mjdsum / real (nfiles)
	if (fn1 == "0")
	    imout = oroot // "_sum.fits"
	else
	    imout = sumseq // "." // oroot // "_avg_" // fn1 // "_" // fn2 // ".fits"
	if (nfiles == 1) {
	    copy (imin1, imout)
	    return
	    }


	combine.input = "@" // templist
	combine.output = imout
	combine.headers = ""
	combine.bpmasks = ""
	combine.rejmasks = ""
	combine.nrejmasks = ""
	combine.expmasks = ""
	combine.sigmas = ""
	combine.ccdtype = ""
	combine.amps = no
	combine.subsets = no
	combine.delete = no
	combine.combine = "average"
	combine.reject = "none"
	combine.project = no
	combine.outtype = "real"
	combine.outlimits = ""
	combine.offsets = "none"
	combine.masktype = "none"
	combine.maskvalue = 0.
	combine.blank = 0.
	combine.scale = "none"
	combine.zero = "none"
	combine.weight = "none"
	combine.statsec = ""
	combine.lthreshold = INDEF
	combine.hthreshold = INDEF
	combine.nlow = 1
	combine.nhigh = 1
	combine.nkeep = 1
	combine.mclip = yes
	combine.lsigma = 3.
	combine.hsigma = 3.
	combine.rdnoise = "0."
	combine.gain = "1."
	combine.snoise = "0."
	combine.sigscale = 0.1
	combine.pclip = -0.5
	combine.grow = 0.

	combine (imagelist, imout)

# Convert time of exposure to mean of added files
	mjdavg = mjdsum / real (nfiles)
	round (mjdavg, "%10.5f")
	hedit (imout, "MJD",round.value,update+,verify-,show=vb)
	gettime (mjdavg, usesec+)
	hedit (imout, "DATE-OBS",gettime.fitsdate,update+,verify-,show=vb)

# Update exposure time to mean of those averaged
	exptot = exptot / real (nfiles)
	round (exptot, "%.1f")
	hedit (imout, "EXPTIME", round.value, update+, verify-,show=vb)

# Make history line including time
	gettime (0.0)
	dstring = gettime.date // " " // gettime.time
	history = dstring // " " // nfiles // " images averaged"
	hedit (imout, "TRSAVG", history, add+, verify-)
	outfile = imout

# Increment sequence number for this directory
	sumseq = sumseq + 1
	trssum.sumseq = sumseq

	if (dellist) {
	    if (access (templist))
		delete (templist)
	    }

end

# Jul 31 2007	New program for TRES pipeline based on TRSSUM
