# File tres/Scripts/trsgroup.cl
# July 30, 2008
# By Doug Mink

# TRSGROUP: Make lists of files to process

procedure trsgroup (images)

string	images="1-300"	{prompt="Files to process"}

string	datedir=""	{prompt="Date for images"}
file	instdir=""	{prompt="Directory containing date directories"}
file	imagedir=""	{prompt="Directory containing images (overrides above)"}
file	datafile="data.db"	{prompt="File for observation database"}
file	sortfile="datasort.db"	{prompt="File for sorted observation database"}
file	objlist="obj.list"	{prompt="File listing groups of observations"}
file	callist="cal.list"	{prompt="File listing groups of calibrations"}
file	flatlist="flat.list"	{prompt="File listing groups of flat fields"}
file	complist="comp.list"	{prompt="File listing groups of ThAr exposures"}
bool	verbose=yes	{prompt="Summarize results (yes or no)"}
bool	debug=no	{prompt="Print file sorting instead of writing files (yes or no)"}

struct *sortlist

begin
    file listname
    file imf, compname
    string imt, obj, mjd, apfib, fibkey, obj0, apfib0
    int lfile, ifile, ical, iexp, ngroups, iobj, icomp, iflat
    real exp, comp, exp0, comp0
    bool savespec

# List all of the data files for this night
    if (access (datafile)) {
	print ("TRSGROUP: Reading database from existing file ",datafile)
	}
    else {
	trslist (images, datedir=datedir, instdir=instdir, imagedir=imagedir,
		 imagetype="", object="",apfib="",aperture="",fibkey="",
		 binning="",fibsize="",exptime="",outlist=datafile,
		 addfib=no,deltemp=yes,overwrite=no,verbose=yes,debug=no)
	if (access (sortfile))
	    delete (sortfile)
	}

# Sort data files by object name, fiber size/binning/numbers, exposure, time
    if (access (sortfile)) {
	print ("TRSGROUP: Reading sorted database from existing file ",sortfile)
	}
    else {
	args = "<" // datafile // " -k7 -k5 -k3 >" // sortfile
	trssort (args)
	}

# Write list files and master list of list files for processing
    obj0 = ""
    apfib0 =""
    exp0 = 0.0
    ifile = 0
    lfile = 0
    iobj = 0
    ical = 0
    icomp = 0
    iflat = 0
    savespec = no
    listname = ""
    sortlist = sortfile
    while (fscan (sortlist,imf,imt,obj,mjd,apfib,fibkey,exp,comp) != EOF) {
#	print ("TRSGROUP: File ", imf)

# Start a new configuration file if the configuration changes
	if (obj != obj0 || apfib != apfib0 || exp != exp0) {
	    if (debug && listname != "") {
		print ("TRSGROUP: ",lfile," files in list ", listname)
		}
	    iexp = int (exp)
	    listname = obj // apfib // "x" //iexp // ".list"
	    compname = obj // apfib // ".list"
	    savespec = no

# Check for existence of file for this object and configuration
	    if (access (listname)) {
		if (verbose)
		    print ("TRSGROUP: Object list file ",listname," already exists")
		next
		}

# Add bias, dark, configuration file names to list
	    if (callist != "" && (obj=="DARK" || obj=="BIAS")) {
		savespec = yes
		if (debug) {
		    if (ical == 0)
			print (listname, " > ", callist)
		    else
			print (listname, " >> ", callist)
		    }
		else {
		    if (ical == 0)
			print (listname, >callist)
		    else
			print (listname, >>callist)
		    if (obj == "COMP")
			if (icomp == 0)
			    print (listname, >callist)
		    }
		ical = ical + 1
		}

# Add ThAr file names to list
	    else if (complist != "" && obj == "COMP") {
		savespec = yes
		if (debug) {
		    if (icomp == 0)
			print (listname, " > ", complist)
		    else
			print (listname, " >> ", complist)
		    }
		else {
		    if (icomp == 0)
			print (listname, >complist)
		    else
			print (listname, >>complist)
		    }
		icomp = icomp + 1
		}

# Add flat field file names to list
	    else if (flatlist != "" && obj == "FLAT") {
		savespec = yes
		if (debug) {
		    if (iflat == 0)
			print (listname, " > ", flatlist)
		    else
			print (listname, " >> ", flatlist)
		    }
		else {
		    if (iflat == 0)
			print (listname, >flatlist)
		    else
			print (listname, >>flatlist)
		    }
		iflat = iflat + 1
		}

# Add object configuration file names to list
	    else if (objlist != "") {
		savespec = yes
		if (debug) {
		    if (iobj == 0)
			print (listname, " > ", objlist)
		    else
			print (listname, " >> ", objlist)
		    }
		else {
		    if (iobj == 0)
			print (listname, >objlist)
		    else
			print (listname, >>objlist)
		    }
		iobj = iobj + 1
		}

	    else if (verbose) {
		print ("TRSGROUP: Not saving ",listname)
		}

# Add ThAr file names to exposure-free list, too
	    if (obj == "COMP") {
		if (debug) {
		    if (access (compname))
			print (imf, " >> ", compname)
		    else
			print (imf, " > ", compname)
		    }

		else {
		    if (access (compname))
			print (imf, >>compname)
		    else
			print (imf, >compname)
		    }
		}

# Save this image file name to the new configuration list file
	    if (debug)
		print (imf, " > ", listname)
	    else if (savespec)
		print (imf, >listname)
	    lfile = 1
	    }

# Save this image file name to the current configuration list file
	else if (savespec) {
	    if (debug)
		print (imf, " >> ",listname)
	    else
		print (imf, >>listname)
	    lfile = lfile + 1
	    }
	ifile = ifile + 1
	exp0 = exp
	apfib0 = apfib
	obj0 = obj
	}

# Summarize the sorting process
    ngroups = iobj + ical + iflat + icomp
    if (verbose)
	print ("TRSGROUP: ", ifile, "files split into ", ngroups, " groups")

    sortlist = ""
end
# Jul 16 2008	New task
# Jul 30 2008	Make additional lists of COMP files by configuration only
