# File tres/Scripts/tcal.cl
# By Doug Mink, SAO Telescope Data Center
# August 14, 2008

# TCAL -- Dispersion correct list of calibration lamp spectra and write
#	  a table of images, MJD's, and shifts

procedure tcal (spectra)

string	spectra = ""	{prompt="Input multispec image(s) to correct"}

string	refroot="comp"	{prompt="Root name for comparison reference file"}
string	refdir="tresdata$" {prompt="Directory for comparison reference file"}
real    shift=0.0       {prompt="Mean pixel shift (returned)"}
bool    interactive=no  {prompt="Run ecidentify on spectrum (yes or no)"}
bool	redo=no		{prompt="Rerun tcreid even if already run (yes or no)"}
bool	deltemp = no	{prompt="Delete temporary files (y or n)"}
bool	saveold = yes	{prompt="Save original file to Nonorm/ (y or n)"}
bool	verbose = yes	{prompt="Log progress (y or n)"}

struct *calfiles

begin
	file imin, templist, imout
	string ims, imroot, fib1, fib2, fib3
	int nshift

	ims = spectra

	tcal1.refroot = refroot
	tcal1.refdir = refdir
	tcal1.redo = redo
	tcal1.interactive = interactive
	tcal1.saveold = saveold
	tcal1.verbose = verbose
	nshift = 0
	shift = 0.0

#  Make temporary list of input files
        templist = mktemp ("tempcomp") // ".list"
        files (ims, >templist)

        calfiles = templist
        while (fscan (calfiles,imin) != EOF) {
	    if (imin == "")
		break
	    smatch (imin, ".ec.")
	    if (smatch.found) {
		if (verbose)
		    print ("TCAL: Processing ", imin)
		tcal1 (imin)
		shift = shift + tcal1.shift
		nshift = nshift + 1
		}
	    else {
		tfib1 (imin)
		fib1 = tfib1.fib1
		fib2 = tfib1.fib2
		fib3 = tfib1.fib3
		fileroot (imin)
		imroot = fileroot.rootname
		if (fib1 == "COMP") {
		    imout = imroot // "_f1.ec.fits"
		    if (verbose)
			print ("TCAL: Processing fiber 1 ", imout)
		    tcal1 (imout)
		    shift = shift + tcal1.shift
		    nshift = nshift + 1
		    }
		if (fib2 == "COMP") {
		    imout = imroot // "_f2.ec.fits"
		    if (verbose)
			print ("TCAL: Processing fiber 2 ", imout)
		    tcal1 (imout)
		    shift = shift + tcal1.shift
		    nshift = nshift + 1
		    }
		if (fib3 == "COMP") {
		    imout = imroot // "_f3.ec.fits"
		    if (verbose)
			print ("TCAL: Processing fiber 3", imout)
		    tcal1 (imout)
		    nshift = nshift + 1
		    shift = shift + tcal1.shift
		    if (verbose)
			print ("TCAL: Returned shift is ",tcal1.shift)
		    }
		}
	    }

# Delete temporary file list if requested
	if (deltemp) {
	    delete (templist)
	    }
	calfiles = ""

# Compute mean pixel shift
	if (verbose)
	    print ("TCAL: shifts= ",shift," nshift= ", nshift)
	shift = shift / real (nshift)

end

# Jan 29 2008	New task to process multiple calibration files at once
# Feb 11 2008	Change name of temporary file from tempcomp* to tempcomp*list
# Mar 11 2008	Change name of reference parameters from id* to ref*
# Mar 11 2008	Make up single fiber names if input list has image files
# Mar 11 2008	Rename task TCAL from TMCAL; call TCAL1, not TCAL
# Mar 15 2008	Add shift parameter to return mean shift
# Mar 15 2008	Add interactive parameter to make running ecidentify optional
# Jun  6 2008	Call TRSFIB1 instead of TRSFIB
# Aug 13 2008	Name files _f1 _f2 _f3 instead of _fib1 _fib2 _fib3
# Aug 13 2008	Use TFIB1 instead of TRSFIB1
# Aug 14 2008	Add redo to redo a night's spectra
# Aug 14 2008	Assign fib1-3 before running TCAL1 because it runs tfib1, too
# Aug 14 2008	Assign imroot before running TCAL1 because it runs fileroot, too
